/* 
 * Programul integreaza f(x) = exp(-x*x )*sin((x-a) * pi/(b-a)) pe intervalul [a,b] prin metoda trapezelor. 
 * Intervalul [a,b] se imparte in N subintervale (x_i,x_(i+1)), de lungime h=(b-a)/N.
 * Valoarea aproximativa a integralei este:
 *             /            
 *         I = | f(x)dx = sum_i {( f(x_i)+f(x_(i+1)) ) * h/2} 
 *             /          
 *  
 * 
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>


#define N 10000
#define SQR(x) ((x)*(x)) 		/* macro functional pentru calculul x^2 */


// functia de integrat
double f(double x, double a, double b)
{
  return exp(- SQR(x) ) * sin((x-a)*M_PI/(b-a));
}

// functia care calculeaza efectiv integrala
double int_T(double left_lim, double right_lim, double a, double b, long Nm)
{
  double h=(right_lim - left_lim)/((double) Nm),				
         Iab = 0.;                     /* valoarea integralei */
  long i;	     		
  
  for(i=0; i < Nm+1; i++)
  {
    double x1 = left_lim + i*h,		/* valoarea x_i */
           x2 = left_lim + (i+1)*h;		/* valoarea x_(i+1) */
    Iab += (f(x1,a,b) + f(x2,a,b));
  }//end-of-for(i<Nm)
  
  Iab = Iab * h/2.;
  return Iab;
} //end-of-int_T()


int main ()
{
  double a, b, lim_inf, lim_sup;			/* limitele domeniului de integrare */
  
  double IT;
  
  // initializare
  lim_inf = a = 0.; lim_sup = b = 8.; 		/* domeniul de integrare */

  IT = int_T(lim_inf,lim_sup,a,b,N);
  printf("******** Integrarea numerica prin metoda trapezelor ********\n");
  printf(" Integrala functiei f(x,a,b) = exp(-x^2)*sin((x-a)*pi/(b-a)), pe [a,b]=[%.2lf,%.2lf]: %.8lf\n\n",a,b,IT);
  return 0;
} //end-of-main()

